@@ -9,7 +9,7 @@ def _get_executable(script_part):
 
 
 def match(command):
-    return (not which(command.script_parts[0])
+    return (not command.script_parts[0] in get_all_executables()
             and _get_executable(command.script_parts[0]))
 
 
